# TODO

-   Maybe sort on original set + number?
    -   weird interleaving happens with some promos
    -   alternatively, only merge PXYZ into XYZ, not other child sets
-   Group sets by parent set is xlsx output?
    -   Block? probably not
-   diffs to stdout
-   Update card_count for sets when processing bundle filters
